@@ -24,22 +24,22 @@ struct CV_EXPORTS_W Params
     /**
      * @brief Constructor for Params
      * Sets the initial pose of the TSDF volume.
-     * @param volumeIntialPoseRot rotation matrix
-     * @param volumeIntialPoseTransl translation vector
+     * @param volumeInitialPoseRot rotation matrix
+     * @param volumeInitialPoseTransl translation vector
      */
-    CV_WRAP Params(Matx33f volumeIntialPoseRot, Vec3f volumeIntialPoseTransl)
+    CV_WRAP Params(Matx33f volumeInitialPoseRot, Vec3f volumeInitialPoseTransl)
     {
-      setInitialVolumePose(volumeIntialPoseRot,volumeIntialPoseTransl);
+      setInitialVolumePose(volumeInitialPoseRot,volumeInitialPoseTransl);
     }
 
     /**
      * @brief Constructor for Params
      * Sets the initial pose of the TSDF volume.
-     * @param volumeIntialPose 4 by 4 Homogeneous Transform matrix to set the intial pose of TSDF volume
+     * @param volumeInitialPose 4 by 4 Homogeneous Transform matrix to set the intial pose of TSDF volume
      */
-    CV_WRAP Params(Matx44f volumeIntialPose)
+    CV_WRAP Params(Matx44f volumeInitialPose)
     {
-      setInitialVolumePose(volumeIntialPose);
+      setInitialVolumePose(volumeInitialPose);
     }
 
     /**
@@ -74,14 +74,22 @@ struct CV_EXPORTS_W Params
     */
     CV_WRAP static Ptr<Params> hashTSDFParams(bool isCoarse);
 
+    /** @brief ColoredTSDF parameters
+      A set of parameters suitable for use with ColoredTSDFVolume
+    */
+    CV_WRAP static Ptr<Params> coloredTSDFParams(bool isCoarse);
+
     /** @brief frame size in pixels */
     CV_PROP_RW Size frameSize;
 
-    CV_PROP_RW cv::kinfu::VolumeType volumeType;
+    /** @brief rgb frame size in pixels */
+    CV_PROP_RW kinfu::VolumeType volumeType;
 
     /** @brief camera intrinsics */
     CV_PROP_RW Matx33f intr;
 
+    /** @brief rgb camera intrinsics */
+    CV_PROP_RW Matx33f rgb_intr;
     /** @brief pre-scale per 1 meter for input values
 
     Typical values are:
@@ -190,6 +198,16 @@ public:
     /** @brief Get current parameters */
     virtual const Params& getParams() const = 0;
 
+    /** @brief Renders a volume into an image
+
+      Renders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.
+      Light pose is fixed in KinFu params.
+
+        @param image resulting image
+    */
+
+    CV_WRAP virtual void render(OutputArray image) const = 0;
+
     /** @brief Renders a volume into an image
 
       Renders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.
@@ -200,7 +218,7 @@ public:
         which is a last frame camera pose.
     */
 
-    CV_WRAP virtual void render(OutputArray image, const Matx44f& cameraPose = Matx44f::eye()) const = 0;
+    CV_WRAP virtual void render(OutputArray image, const Matx44f& cameraPose) const = 0;
 
     /** @brief Gets points and normals of current 3d mesh
 
